pub(super) async fn close_channel(
_env: &MountainEnvironment,
_channel_identifier: String,
) -> Result<(), CommonError>Expand description
Closes the view of an output channel in the UI.
pub(super) async fn close_channel(
_env: &MountainEnvironment,
_channel_identifier: String,
) -> Result<(), CommonError>Closes the view of an output channel in the UI.